@@ -15,8 +15,17 @@ EMAIL_CHANGE_NOTIFICATION_EMAIL_TEMPLATE = getattr(settings,
 
 EMAIL_CHANGE_NOTIFICATION_FROM = getattr(settings, "EMAIL_CHANGE_NOTIFICATION_FROM", "no-reply@example.com")
 
-EMAIL_CHANGE_ACTIVATION_SUCCESS_URL = getattr(settings, "EMAIL_CHANGE_ACTIVATION_SUCCESS_URL", "/user-email-changed")
+EMAIL_CHANGE_ACTIVATION_SUCCESS_URL = getattr(settings,
+                                              "EMAIL_CHANGE_ACTIVATION_SUCCESS_URL", "django_change_email_sent_activation_email")
 
-EMAIL_CHANGE_SUCCESS_URL = getattr(settings, "EMAIL_CHANGE_SUCCESS_URL", "/new-email-activation-sent")
+EMAIL_CHANGE_SUCCESS_URL = getattr(settings, "EMAIL_CHANGE_SUCCESS_URL", "django_change_email_sent_activation_email")
 
-CHANGE_EMAIL_CODE_EXPIRY_TIME = getattr(settings, "CHANGE_EMAIL_CODE_EXPIRY_TIME", {"days": 3})
\ No newline at end of file
+CHANGE_EMAIL_CODE_EXPIRY_TIME = getattr(settings, "CHANGE_EMAIL_CODE_EXPIRY_TIME", {"days": 3})
+
+EMAIL_CHANGE_NOTIFICATION_SENT_TEMPLATE = getattr(settings,
+                                                  "EMAIL_CHANGE_NOTIFICATION_SENT_TEMPLATE",
+                                                  "django_email_changer/email_notification_sent.html")
+
+EMAIL_CHANGE_SUCCESSS_TEMPLATE = getattr(settings,
+                                         "EMAIL_CHANGE_SUCCESSS_TEMPLATE",
+                                         "django_email_changer/email_change_success.html")
\ No newline at end of file
